@@ -1249,6 +1249,8 @@ gm_conf_notifier_remove (gpointer identifier)
   g_return_if_fail (identifier != NULL);
 
   g_datalist_foreach (&db->entries, entry_remove_notifier_in_list, identifier);
+
+  notifier_destroy (identifier);
 }
 
 void
@@ -1479,13 +1481,13 @@ gm_conf_is_key_writable (gchar *key)
 }
 
 gchar *
-gm_conf_escape_key (gchar *key, gint len)
+gm_conf_escape_key (const gchar *key, gint len)
 {
   return g_strescape (key, NULL); /* we don't honor len */
 }
 
 gchar *
-gm_conf_unescape_key (gchar *key, gint len)
+gm_conf_unescape_key (const gchar *key, gint len)
 {
   return g_strcompress (key); /* we don't honor len */
 }
